from distutils.core import setup
setup(
  name = 'ybc_camera',
  packages = ['ybc_camera'],
  version = '1.0.0',
  description = 'ybc camera',
  long_description='ybc camera',
  author = 'KingHS',
  author_email = '382771946@qq.com',
  keywords = ['pip3', 'python3','python','camera'],
  license='MIT',
  install_requires=['opencv-python']
)
